@@ -21,11 +21,11 @@
  * the project's page is at http://linuxtv.org/dvd/
  *
  * Removed all CSS related stuff to be able to publish "regionset"
- *   by Mirko Dlle <cooper@linvdr.org>
+ *   by Mirko Doelle <cooper@linvdr.org>
  */
  
 /* This is needed for 64 bit file seek */
-// Since older libraries don't seem to support this, i did a workaround
+/* Since older libraries don't seem to support this, i use a workaround */
 #define _LARGEFILE64_SOURCE 1
 
 #include <stdio.h>
@@ -254,7 +254,7 @@ int Unicodedecode(u8 *data, int len, char *target)
 int UDFEntity(u8 *data, u8 *Flags, char *Identifier) 
 {
 	*Flags = data[0];
-	strncpy(Identifier, &data[1], 5);
+	strncpy(Identifier, (const char*) &data[1], 5);
 	return 0;
 }
 
@@ -326,14 +326,14 @@ int UDFPartition(u8 *data, u16 *Flags, u16 *Number, char *Contents, u32 *Start,
 // returns 0 on OK, 1 on error
 int UDFLogVolume(u8 *data, char *VolumeDescriptor) 
 {
-	u32 lbsize, MT_L, N_PM;
+	u32 lbsize; // , MT_L, N_PM;
 	//u8 type, PM_L;
 	//u16 sequence;
 	//int i, p;
 	Unicodedecode(&data[84], 128, VolumeDescriptor);
 	lbsize = GETN4(212);  // should be 2048
-	MT_L = GETN4(264);    // should be 6
-	N_PM = GETN4(268);    // should be 1
+	//MT_L = GETN4(264);    // should be 6
+	//N_PM = GETN4(268);    // should be 1
 	if (lbsize != DVD_VIDEO_LB_LEN) return 1;
 	/*
 	*Partition1 = 0;
